@@ -2,7 +2,7 @@ result <-
 function(fit){
 #GAM = fit[-1,]; OBJ = fit[1,]
 
-  GAM = fit$GAM; OBJ = fit$OBJ
+  GAM = fit$GAM; OBJ = fit$OBJ; tuning= fit$tuning
 p = nrow(GAM)
   marg.gam = rep(0,p)
 for(u in 1:ncol(GAM)){
@@ -14,5 +14,8 @@ ind2 = which(gam0==1)
 post = exp(OBJ-max(OBJ))/sum(exp(OBJ-max(OBJ)))
 hppm = 1/sum(exp(OBJ-max(OBJ)))
 print("# of Searched Models by S5");print(length(OBJ))
-return(list(hppm = which(gam0==1), hppm.prob = hppm, marg.prob = marg.gam,gam = GAM, obj = OBJ) )
+print("The MAP model is ")
+print(which(gam0==1))
+print(paste("with posterior probability",round(hppm,3) )) 
+return(list(hppm = which(gam0==1), hppm.prob = hppm, marg.prob = marg.gam,gam = GAM, obj = OBJ, post = post, tuning = tuning) )
 }
